/*--
 Copyright (C) 2005 Tim Solley.
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
 notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
 notice, this list of conditions, and the disclaimer that follows
 these conditions in the documentation and/or other materials
 provided with the distribution.

 3. The name "Deadbolt" may be used to endorse or promote products
 derived from this software without prior written permission.

 4. Products derived from this software may not be called "Deadbolt", nor
 may "Deadbolt" appear in their name, without prior written permission
 from the Deadbolt Project Management timsolley@yahoo.com.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 "This product includes software developed by the
 Deadbolt Project (http://deadbolt.sourceforge.net/)."
 Alternatively, the acknowledgment may be graphical using the logos
 available at http://deadbolt.sourceforge.net.

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE DEADBOLT AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 This software consists of voluntary contributions made by many
 individuals on behalf of the Deadbolt Project and was originally
 created by Tim Solley timsolley@yahoo.com.  For more information
 on the Deadbolt Project, please see <http://deadbolt.sourceforge.net/>.
 */

package net.sf.deadbolt.model;

import java.util.Map;
import java.util.TreeMap;

/**
 * This class is a value object that contains information about a Room. This
 * includes information such as the list of Handlers, the error page, and any
 * initial parameters.
 * 
 * @author Tim Solley <timsolley@yahoo.com>
 */
public class Room {
    private TreeMap handlers;

    private String errorPage;

    private Map initParams;

    /**
     * @return Returns the initParams.
     */
    public Map getInitParams() {
        return initParams;
    }

    /**
     * @param initParams
     *            The initParams to set.
     */
    public void setInitParams(Map initParams) {
        this.initParams = initParams;
    }

    /**
     * @return Returns the errorPage.
     */
    public String getErrorPage() {
        return errorPage;
    }

    /**
     * @param errorPage
     *            The errorPage to set.
     */
    public void setErrorPage(String errorPage) {
        this.errorPage = errorPage;
    }

    /**
     * @return Returns the handler.
     */
    public TreeMap getHandlers() {
        return handlers;
    }

    /**
     * @param handler
     *            The handler to set.
     */
    public void setHandler(TreeMap handlers) {
        this.handlers = handlers;
    }
    
    /**
     * 
     * @param key
     * @return
     */
    public String getInitParam(String key) {
        return (String) initParams.get(key);
    }
    
    /**
     * Returns whether an initial parameter with this name exists.  Useful for
     * checking params in your handlers.
     * @param key
     * @return
     */
    public boolean initParamExists(String key) {
        if(initParams.get(key) == null) {
            return false;
        } else {
            return true;
        }
    }
}